##  Configuring Matching Rules
Follow these steps:
  1. On the integration configuration page, go to the Mappings tab.
  2. Under Fact Sheet Mappings, hover over the desired mapping, then click Configuration under Field Mapping.
  3. On the field mapping page that opens, go to the Matching Rules tab.
  4. To set up a matching rule, click Add Field, then select fields in the source and target systems. When adding multiple fields, place them in the correct order. A preview of the matching rule appears.
![Configuring Matching Rules in a Fact Sheet Mapping](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c6a9a7a44101481feb3eae2dfe837_LowRes.png)
Configuring Matching Rules in a Fact Sheet Mapping
  5. Click Confirm, then save your changes.


**Note**
The source and target systems in matching rules depend on the data direction set up in a fact sheet mapping.
